0.9.9 API documentation: GLM_EXT_scalar_constants

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_EXT_scalar_constants
Stable extensions

Provides a list of constants and precomputed useful values. More...

## Functions
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | epsilon ()
| Return the epsilon constant for floating point types.
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | pi ()
| Return the pi constant for floating point types.

## Detailed Description

Provides a list of constants and precomputed useful values.

Include <glm/ext/scalar_constants.hpp> to use the features of this extension.